@@ -12,16 +12,22 @@ for which a new license (GPL+exception) is in place.
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
- #include "about.h"
+#include "about.h"
 #include "about.moc"
 #include <qpixmap.h>
 #include <qtextstream.h>
 #include <qtooltip.h>
+#include <qlabel.h>
+#include <qtabwidget.h>
+#include <qwidget.h>
+#include <qpushbutton.h>
+#include <qlayout.h>
 
 #include "commonstrings.h"
 #include "scconfig.h"
 #include "gsutil.h"
 #include "util.h"
+#include "helpbrowser.h" // due the TextBrowser (for html browsing)
 #include "upgradechecker.h"
 #include "langmgr.h"
 
@@ -29,8 +35,8 @@ extern QPixmap loadIcon(QString nam);
 
 /*!
  \fn About::About( QWidget* parent )
- \author Franz Schmid 
- \date  
+ \author Franz Schmid
+ \date
  \brief Constructor for About dialog box
  \param parent QWidget pointer to parent window
  \retval About dialog
@@ -54,8 +60,8 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 	tabLayout1->addWidget( pixmapLabel1 );
 	buildID = new QLabel( tab, "BB" );
 	buildID->setAlignment(Qt::AlignCenter);
-	QString BUILD_DAY = "09";
-	QString BUILD_MONTH = CommonStrings::january;
+	QString BUILD_DAY = "27";
+	QString BUILD_MONTH = CommonStrings::may;
 	QString BUILD_YEAR = "2007";
 	QString BUILD_TIME = "";
 	QString BUILD_TZ = "";
@@ -73,11 +79,7 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 		 built = tr("%3-%2-%1 %4 %5").arg(BUILD_DAY).arg(BUILD_MONTH).arg(BUILD_YEAR).arg(BUILD_TIME).arg(BUILD_TZ);
 
 	QString bu;
-#ifdef HAVE_CMS
 	bu += "C";
-#else
-	bu += "*";
-#endif
 	bu += "-";
 #ifdef HAVE_CUPS
 	bu += "C";
@@ -85,11 +87,7 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 	bu += "*";
 #endif
 	bu += "-";
-#ifdef HAVE_TIFF
 	bu += "T";
-#else
-	bu += "*";
-#endif
 	bu += "-";
 #ifdef HAVE_FONTCONFIG
 	bu += "F";
@@ -118,7 +116,7 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 #  else
 	bu += "?";
 #  endif
-#else 
+#else
 	int wordSize;
 	bool bigEndian;
 	qSysInfo( & wordSize, & bigEndian );
@@ -143,24 +141,24 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 	textView1 = new TextBrowser( tab_2, "TextView1" );
 	textView1->setText(QString::fromUtf8("<table><tr><td><b>" + tr("Development Team:").utf8() + "</b></td><td> </td></tr>" +
 											"<tr><td>Franz Schmid</td><td>Franz.Schmid@altmuehlnet.de</td></tr>" +
-											"<tr><td>Peter Linnell</td><td>mrdocs@scribus.info</td></tr>" + 
-											"<tr><td>Paul F. Johnson</td><td>paul@all-the-johnsons.co.uk</td></tr>" +
+											"<tr><td>Peter Linnell</td><td>mrdocs@scribus.info</td></tr>" +
 											"<tr><td>Craig Bradney</td><td>cbradney@zip.com.au</td></tr>" +
 											"<tr><td>Petr Vaněk</td><td>petr@yarpen.cz</td></tr>" +
 											"<tr><td>Riku Leino</td><td>riku@scribus.info</td></tr>" +
 											"<tr><td>Craig Ringer</td><td>craig@postnewspapers.com.au</td></tr>" +
 											"<tr><td>Andreas Vox</td><td>avox@arcor.de</td></tr>" +
 											"<tr><td>Jean Ghali</td><td>jghali@libertysurf.fr</td></tr>" +
+											"<tr><td>Oleksandr Moskalenko</td><td>malex@tagancha.org</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-
 											"<tr><td><b>" + tr("Contributions from:").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td>Paul F. Johnson</td><td>paul@all-the-johnsons.co.uk</td></tr>" +
 											"<tr><td>Niyam Bhushan</td><td></td></tr>" +
 											"<tr><td>Martin Costabel</td><td></td></tr>" +
-											"<tr><td>Steve Callcott</td><td>stotte@ntlworld.com</td></tr>" +
+											"<tr><td>Steve Callcott</td><td>stotte@firstwish.co.uk</td></tr>" +
 											"<tr><td>Frank Everdij</td><td>f.everdij@citg.tudelft.nl</td></tr>" +
 											"<tr><td>S. Hakim Hamdani</td><td>hakimoto@eroteme.org</td></tr>" +
 											"<tr><td>Maciej Hański</td><td>m.hanski@gmx.at</td></tr>" +
-											"<tr><td>Oleksandr Moskalenko</td><td>malex@tagancha.org</td></tr>" +
+											"<tr><td>Paul F. Johnson</td><td>paul@all-the-johnsons.co.uk</td></tr>" +
 											"<tr><td>Marti Maria</td><td></td></tr>" +
 											"<tr><td>Alexandre Prokoudine</td><td>alexandre.prokoudine@gmail.com</td></tr>"
 											"<tr><td>Alessandro Rimoldi</td><td>http://ideale.ch/contact</td></tr>" +
@@ -185,21 +183,25 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 											"<tr><td> </td><td> </td></tr>" +
 
 											"<tr><td><b>" + tr("Official Documentation:").utf8()  + "</b></td><td></td></tr>" +
-											"<tr><td>Peter Linnell</td><td>mrdocs@scribus.info</td></tr>" + 
+											"<tr><td>Peter Linnell</td><td>mrdocs@scribus.info</td></tr>" +
 											"<tr><td>Craig Bradney</td><td>cbradney@zip.com.au</td></tr>" +
 											"<tr><td>Frédéric Dubuy</td><td>effediwhy@gmail.com</td></tr>" +
-											"<tr><td>Johannes Rüschel</td><td>jo.rueschel@gmx.de</td></tr>" 
-											+"<tr><td>Volker Ribbert</td><td>volkerius@h3c.de</td></tr>" + 
-											"<tr><td>Louis Desjardins</td><td>louisdesjardins@videotron.ca</td></tr>" + 
+											"<tr><td>Johannes Rüschel</td><td>jo.rueschel@gmx.de</td></tr>"
+											+"<tr><td>Volker Ribbert</td><td>volkerius@h3c.de</td></tr>" +
+											"<tr><td>Louis Desjardins</td><td>louisdesjardins@videotron.ca</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + tr("Other Documentation:").utf8()  + "</b></td><td></td></tr>" +
-											"<tr><td>Yves Ceccone</td><td>yves@yeccoe.org</td></tr>" + 
+											"<tr><td>Yves Ceccone</td><td>yves@yeccoe.org</td></tr>" +
 											"<tr><td>Holger Reibold</td><td>http://www.bomots.de/scribus/</td></tr>" +
 											"<tr><td>Thomas Zastrow</td><td>webmaster@thomas-zastrow.de</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
+											"<tr><td><b>" + tr("Splash Screen:").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td>Andy Fitzsimon</td><td>andrew@fitzsimon.com.au</td></tr>" +
+											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + tr("Tango Project Icons:").utf8()  + "</b></td><td></td></tr>" +
 											"<tr><td>Andreas Nilsson</td><td>nisses.mail@home.se</td></tr>" +
-											"<tr><td>Jakub Steiner</td><td>jimmac@ximian.com</td></tr>"  + 
+											"<tr><td>Jakub Steiner</td><td>jimmac@ximian.com</td></tr>"  +
+											"<tr><td>Antoine Cailliau</td><td>antoinecailliau@gmail.com</td></tr>"  +
 											"<tr><td> </td><td> </td></tr>" + "</table>"));
 	tabLayout->addWidget( textView1 );
 	tabWidget2->insertTab( tab_2, tr( "A&uthors" ) );
@@ -211,151 +213,170 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 	LanguageManager langmgr;
 	langmgr.init(false);
 	textView2->setText(QString::fromUtf8( "<table><tr><td><b><i>" + tr("Official Translations and Translators:").utf8() + "</i></b></td><td></td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("af").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("af").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Kobus Wolvaardt</td><td>kobuswolf@diewereld.co.za</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("eu").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" +
+											langmgr.getLangFromAbbrev("eu").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Iñaki Larrañaga Murgoitio</td><td>dooteo@euskalgnu.org</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("br").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("br").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Alan Monfort</td><td>alan.monfort@free.fr</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("ca").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("ca").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Xavier Sala Pujolar</td><td>utrescu@xaviersala.net</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("cs").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("zh_TW").local8Bit()  + "</b></td><td> </td></tr>" +
+											"<tr><td>Gilbert Su</td><td>gilbert_su@yahoo.com.tw</td></tr>" +
+											"<tr><td> </td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("cs").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Petr Vaněk</td><td>petr@yarpen.cz</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("da").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("da").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Morten Langlo</td><td>mlanglo@mail.dk</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("nl").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("nl").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Foppe Benedictus</td><td>foppe.benedictus@gmail.coml</td></tr>" +
 											"<tr><td>Erik Collou</td><td>collou@gmx.net</td></tr>" +
-											"<tr><td>Wilbert Berendsen</td><td>wbsoft@xs4all.nl</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("en_AU").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" +
+											langmgr.getLangFromAbbrev("en_AU").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Craig Bradney</td><td>cbradney@zip.com.au</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("en_GB").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" +
+											langmgr.getLangFromAbbrev("en_GB").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Craig Bradney</td><td>cbradney@zip.com.au</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("eo").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("eo").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Pier Luigi Cinquantini</td><td>plcinquantini@katamail.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("et").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("et").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Marek Laane</td><td>bald@starman.ee</td></tr>" +
 											"<tr><td>Hasso Tepper</td><td>hasso@estpak.ee</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("fi").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("fi").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Riku Leino</td><td>riku@scribus.info</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("fr").utf8()  + "</b></td><td> </td>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("fr").local8Bit()  + "</b></td><td> </td>" +
 											"<tr><td>Nicolas Boos</td><td>nicolas.boos@wanadoo.fr</td></tr>" +
 											"<tr><td>Louis Desjardins</td><td>louis_desjardins@mardigrafe.com</td></tr>" +
 											"<tr><td>Frédéric Dubuy</td><td>effediwhy@gmail.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("de").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("de").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Johannes Rüschel</td><td>jo.rueschel@gmx.de</td></tr>" +
 											"<tr><td>Franz Schmid</td><td>Franz.Schmid@altmuehlnet.de</td></tr>" +
 											"<tr><td>Christoph Schäfer</td><td>christoph-schaefer@gmx.de</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("ga").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("de_CH").local8Bit()  + "</b></td><td> </td></tr>" +
+											"<tr><td>Christoph Schäfer</td><td>christoph-schaefer@gmx.de</td></tr>" +
+											"<tr><td> </td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("de_ol").local8Bit()  + "</b></td><td> </td></tr>" +
+											"<tr><td>Johannes Rüschel</td><td>jo.rueschel@gmx.de</td></tr>" +
+											"<tr><td>Christoph Schäfer</td><td>christoph-schaefer@gmx.de</td></tr>" +
+											"<tr><td> </td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("ga").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Xose Calvo</td><td>xosecalvo@galizaweb.net</td></tr>" +
 											"<tr><td>Manuel Anxo Rei</td><td>manxopar@avogaciagalega.org</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("el").utf8()  + "</b></td><td> </td></tr>" +
-											"<tr><td>Toussis Manolis</td><td>manolis@koppermind.homelinux.org</td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("el").local8Bit()  + "</b></td><td> </td></tr>" +
+											"<tr><td>Τούσης Μανώλης </br> Toussis Manolis</td><td>manolis@koppermind.homelinux.org</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("hu").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("hu").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Csaba Zakarias</td><td>csaba.zakarias@gmail.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("it").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("it").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Pier Luigi Cinquantini</td><td>plcinquantini@katamail.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("ja").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("ja").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Shushi Kurose</td><td>md81@bird.email.ne.jp</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("ko").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("ko").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Kitae Kim</td><td>neeum@yahoo.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"<tr><td><b>" + langmgr.getLangFromAbbrev("nb").utf8()  + "</b></td><td></td></tr>" +
 											"<tr><td>Axel Bojer</td><td>axelb@skolelinux.no</td></tr>" +
 											"<tr><td>Klaus Ade Johnstad</td><td>klaus@inout.no</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("pl").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("pl").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Maciej Hański</td><td>m.hanski@gmx.at</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("pt_BR").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("pt").local8Bit()  + "</b></td><td> </td></tr>" +
+											"<tr><td>Fausto Guilherme</td><td>faustoguilherme@gmail.com</td></tr>" +
+											"<tr><td> </td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("pt_BR").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Ludi Maciel</td><td>iludi@uol.com.br</td></tr>" +
 											"<tr><td>Frederico Gon&#231;alves</td><td></td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("ru").utf8()  + "</b></td><td></td></tr>" +
-											"<tr><td>Alexandre Prokoudine</td><td>alexandre.prokoudine@gmail.com</td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("ru").local8Bit()  + "</b></td><td></td></tr>" +
+											"<tr><td>Александр Прокудин </td><td>alexandre.prokoudine@gmail.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("sr").utf8()  + "</b></td><td></td></tr>" +
-											"<tr><td>Bojan Božovi&#263;</td><td>bole89@infosky.net</td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("sr").local8Bit()  + "</b></td><td></td></tr>" +
+											"<tr><td>Bojan Božovi&#263;</td><td>bole89@infosky.net</td></tr>"+
+											"<tr><td>Vladimir Savic</td><td>vladimir.firefly.savic@gmail.com</td></tr>"+
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("sk").utf8()  + "</b></td><td></td></tr>" +
-											"<tr><td>Zdenko Podobn&yacute;</td><td>zdpo@mailbox.sk</td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("sk").local8Bit()  + "</b></td><td></td></tr>" +
+											"<tr><td>Zdenko Podobn&yacute;</td><td>zdposter@gmail.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("sl").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("sl").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Boštjan Špetič</td><td>igzebedze@kiberpipa.org</td></tr>" +
 											"<tr><td>Peter Čuhalev</td><td>skatey@slocartoon.net</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("es_ES").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("es_ES").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Josep Febrer</td><td>josep@linuxmail.org</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("sv").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("sv").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Göran Bondeson</td><td>goran@bondeson.net</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("th_TH").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("th_TH").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Sira Nokyoungthong</td><td>Sira Nokyoungthong</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("tr").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("tr").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Barış Atasoy</td><td>batasoy@pozitifpc.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("uk").utf8()  + "</b></td><td> </td></tr>" +
-											"<tr><td>Oleksandr Moskalenko</td><td>malex@tagancha.org</td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("uk").local8Bit()  + "</b></td><td> </td></tr>" +
+											"<tr><td>Олександр Москаленко <br>Oleksandr Moskalenko</td><td>malex@tagancha.org</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("cy").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("cy").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Kevin Donnelly</td><td>kevin@dotmon.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"</table>" +
-											"<table><tr><td><b><i>" + tr("Previous Translation Contributors:").utf8() + "</i></b></td><td></td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("eu").utf8() + "</b></td><td></td></tr>" +
+											"<table><tr><td><b><i>" + tr("Previous Translation Contributors:").local8Bit() + "</i></b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("eu").local8Bit() + "</b></td><td></td></tr>" +
 											"<tr><td>Pablo Saratxaga</td><td>pablo@mandrakesoft.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("pt_BR").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("pt_BR").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Celio Santos</td><td>celio@electronic.srv.br</td></tr>" +
 											"<tr><td>Cezar de Souza Marson Nido</td><td>cesar@electronic.srv.br</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("bg").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("bg").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Vasko Tomanov</td><td>vasko@web.bg</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("en_GB").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("nl").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td>Wilbert Berendsen</td><td>wbsoft@xs4all.nl</td></tr>" +
+											"<tr><td> </td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("en_GB").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Paul F. Johnson</td><td>paul@all-the-johnsons.co.uk</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("fr").utf8()  + "</b></td><td> </td>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("fr").local8Bit()  + "</b></td><td> </td>" +
 											"<tr><td>Michel Briand</td><td>michelbriand@free.fr</td></tr>" +
 											"<tr><td>Yves Ceccone</td><td>yves@yeccoe.org</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("hu").utf8()  + "</b></td><td> </td></tr>" +
+
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("hu").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Giovanni Biczó</td><td>gbiczo@freestart.hu</td></tr>" +
 											"<tr><td>Bence Nagy</td><td>scribus@tipogral.hu</td></tr>" +
 											"<tr><td>Zoltán Böszörményi</td><td>zboszor@freemail.hu</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("lt").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("lt").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Aivaras Kirejevas</td><td>kiras@mail.lt</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("nb").utf8()  + "</b></td><td></td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("nb").local8Bit()  + "</b></td><td></td></tr>" +
 											"<tr><td>Johannes Wilm</td><td>j@indymedia.no</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("tr").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("tr").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Erkan Kaplan</td><td>Selamsana@uni.de</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
-											"<tr><td><b>" + langmgr.getLangFromAbbrev("uk").utf8()  + "</b></td><td> </td></tr>" +
+											"<tr><td><b>" + langmgr.getLangFromAbbrev("uk").local8Bit()  + "</b></td><td> </td></tr>" +
 											"<tr><td>Sergiy Kudryk</td><td>kudryk@yahoo.com</td></tr>" +
 											"<tr><td> </td><td> </td></tr>" +
 											"</table>"));
@@ -382,9 +403,7 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 	tabLayout_4->setMargin( 10 );
 	tabLayout_4->addWidget( textView4 );
 	tabWidget2->insertTab( tab_4, tr( "&Online" ) );
-
 	// Update tab
-/*
 	tab_5 = new QWidget( tabWidget2, "tab_5" );
 	tabWidget2->insertTab( tab_5, tr( "&Updates" ) );
 	updateLayout = new QVBoxLayout( tab_5 );
@@ -394,10 +413,9 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 	textView5 = new TextBrowser( tab_5, "TextView5" );
 	updateLayout->addWidget( checkForUpdateButton );
 	updateLayout->addWidget( textView5 );
-*/
-
 
 	aboutLayout->addWidget( tabWidget2 );
+
 	layout2 = new QHBoxLayout;
 	layout2->setSpacing( 6 );
 	layout2->setMargin( 0 );
@@ -412,11 +430,11 @@ About::About( QWidget* parent ) : QDialog( parent, "About", true, 0 )
 
 //tooltips
 
-	QToolTip::add( buildID, "<qt>" + tr( "This panel shows the version, build date and compiled in library support in Scribus. The C-C-T-F equates to C=littlecms C=CUPS T=TIFF support F=Fontconfig support. Last Letter is the renderer C=cairo or A=libart Missing library support is indicated by a *. This also indicates the version of Ghostscript which Scribus has detected." ) + "</qt>" );
-//	QToolTip::add( checkForUpdateButton, "<qt>" + tr( "Check for updates to Scribus. No data from your machine will be transferred off it." ) + "</qt>" );
+	QToolTip::add( buildID, "<qt>" + tr( "This panel shows the version, build date and compiled in library support in Scribus. The C-C-T-F equates to C=littlecms C=CUPS T=TIFF support F=Fontconfig support. Last Letter is the renderer C=cairo or A=libart Missing library support is indicated by a *. This also indicates the version of Ghostscript which Scribus has detected. The Windows version does not use fontconfig or CUPS libraries." ) + "</qt>" );
+	QToolTip::add( checkForUpdateButton, "<qt>" + tr( "Check for updates to Scribus. No data from your machine will be transferred off it." ) + "</qt>" );
 	// signals and slots connections
 	connect( okButton, SIGNAL( clicked() ), this, SLOT( accept() ) );
-//	connect( checkForUpdateButton, SIGNAL( clicked() ), this, SLOT( runUpdateCheck() ) );
+	connect( checkForUpdateButton, SIGNAL( clicked() ), this, SLOT( runUpdateCheck() ) );
 }
 
 void About::runUpdateCheck()
@@ -425,4 +443,3 @@ void About::runUpdateCheck()
 	bool error=uc.fetch();
 	uc.show(error);
 }
-
