@@ -7,16 +7,18 @@ for which a new license (GPL+exception) is in place.
 #include "scfonts.h"
 #include "annot.h"
 #include "annot.moc"
+#include "annotation.h"
+#include "cmsettings.h"
 #include "editor.h"
-#include "selfield.h"
 #include "customfdialog.h"
 #include "buttonicon.h"
-#include "annotation.h"
+
 #include "mpalette.h"
+#include "selfield.h"
 #include <qstringlist.h>
 #include <qdatetime.h>
 #include <qpixmap.h>
-#include "colorm.h"
+#include "colorlistbox.h"
 #include "prefsmanager.h"
 #include "prefsfile.h"
 #include "scimage.h"
@@ -35,6 +37,7 @@ extern QPixmap loadIcon(QString nam);
 Annot::Annot(QWidget* parent, PageItem *it, int Seite, int b, int h, ColorList Farben, ScribusView* vie)
 		: QDialog( parent, "AN", true, 0 )
 {
+	ScribusDoc* doc = Farben.document();
 	setCaption( tr( "Field Properties" ) );
 	setIcon(loadIcon("AppIcon.png"));
 	item = it;
@@ -106,7 +109,7 @@ Annot::Annot(QWidget* parent, PageItem *it, int Seite, int b, int h, ColorList F
 	OldName = item->itemName();
 
 	TextLabel30 = new QLabel( GroupBox10, "TextLabel3" );
-	TextLabel30->setText( tr( "Tool-Tip:" ) );
+	TextLabel30->setText( tr( "Tooltip:" ) );
 	Layout60->addWidget( TextLabel30, 1, 0);
 	GroupBox10Layout->addLayout( Layout60 );
 
@@ -156,12 +159,12 @@ Annot::Annot(QWidget* parent, PageItem *it, int Seite, int b, int h, ColorList F
 	GroupBox20Layout->addWidget( TextLabel40a, 0, 0 );
 	BorderC = new ColorCombo( true, GroupBox20, "BorderC" );
 	ColorList::Iterator cit;
-	BorderC->insertItem(CommonStrings::NoneColor);
+	BorderC->insertItem(CommonStrings::tr_NoneColor);
 	if (item->annotation().borderColor() == CommonStrings::None)
 		BorderC->setCurrentItem(BorderC->count()-1);
 	for (cit = Farben.begin(); cit != Farben.end(); ++cit)
 	{
-		BorderC->insertSmallItem(Farben[cit.key()], cit.key());
+		BorderC->insertSmallItem(cit.data(), doc, cit.key());
 		if (cit.key() == item->annotation().borderColor())
 			BorderC->setCurrentItem(BorderC->count()-1);
 	}
@@ -172,7 +175,7 @@ Annot::Annot(QWidget* parent, PageItem *it, int Seite, int b, int h, ColorList F
 	GroupBox20Layout->addWidget( TextLabel40, 1, 0 );
 	BorderW = new QComboBox( true, GroupBox20, "BorderW" );
 	// PFJ - 28/02/04 - Altered to the QString/size_t/for style
-	QString borders[] = {CommonStrings::NoneColor, tr("Thin"), tr("Normal"), tr("Wide")};
+	QString borders[] = {CommonStrings::tr_NoneColor, tr("Thin"), tr("Normal"), tr("Wide")};
 	size_t bordersArray = sizeof(borders) / sizeof(*borders);
 	for (uint propogate = 0; propogate < bordersArray; ++propogate)
 		BorderW->insertItem(borders[propogate]);
@@ -214,7 +217,7 @@ Annot::Annot(QWidget* parent, PageItem *it, int Seite, int b, int h, ColorList F
 	Required->setChecked(item->annotation().Flag() & 2);
 	GroupBox30Layout->addMultiCellWidget( Required, 1, 1, 0, 1 );
 	NoExport = new QCheckBox( GroupBox30, "NoExport" );
-	NoExport->setText( tr( "Don't Export Value" ) );
+	NoExport->setText( tr( "Do Not Export Value" ) );
 	if (item->annotation().Type() == 2)
 		NoExport->setEnabled(false);
 	NoExport->setChecked(item->annotation().Flag() & 4);
@@ -353,24 +356,25 @@ Annot::Annot(QWidget* parent, PageItem *it, int Seite, int b, int h, ColorList F
 	{
 		QPixmap pmI1;
 		ScImage im;
+		CMSettings cms(view->Doc, "", 0);
 		if (!item->Pfile.isEmpty())
 		{
-			im.LoadPicture(item->Pfile, "", 0, false, false, 1, 72);
-			pmI1.convertFromImage(im);
+			im.LoadPicture(item->Pfile, cms, false, false, ScImage::RGBData, 72);
+			pmI1.convertFromImage(im.qImage());
 			NiconPrev->setPixmap(pmI1);
 			IconNR->setEnabled(true);
 		}
 		if (!item->Pfile2.isEmpty())
 		{
-			im.LoadPicture(item->Pfile2, "", 0, false, false, 1, 72);
-			pmI1.convertFromImage(im);
+			im.LoadPicture(item->Pfile2, cms, false, false, ScImage::RGBData, 72);
+			pmI1.convertFromImage(im.qImage());
 			PiconPrev->setPixmap(pmI1);
 			IconPR->setEnabled(true);
 		}
 		if (!item->Pfile3.isEmpty())
 		{
-			im.LoadPicture(item->Pfile3, "", 0, false, false, 1, 72);
-			pmI1.convertFromImage(im);
+			im.LoadPicture(item->Pfile3, cms, false, false, ScImage::RGBData, 72);
+			pmI1.convertFromImage(im.qImage());
 			RiconPrev->setPixmap(pmI1);
 			IconRR->setEnabled(true);
 		}
@@ -618,12 +622,12 @@ Annot::Annot(QWidget* parent, PageItem *it, int Seite, int b, int h, ColorList F
 	SpinBox11 = new QSpinBox( GroupBox11, "SpinBox1" );
 	SpinBox11->setMinValue(1);
 	SpinBox11->setMaxValue(item->annotation().ActionType() == 7 ? 1000 : Seite);
-	SpinBox11->setValue(item->annotation().Ziel()+1);
+	SpinBox11->setValue(QMIN(item->annotation().Ziel()+1, Seite));
 	GroupBox11Layout->addWidget( SpinBox11, 1, 1 );
 	if (item->annotation().ActionType() == 7)
 		Pg1 = new Navigator( GroupBox11, 100, item->annotation().Ziel()+1, view, item->annotation().Extern());
 	else
-		Pg1 = new Navigator( GroupBox11, 100, item->annotation().Ziel(), view);
+		Pg1 = new Navigator( GroupBox11, 100, QMIN(item->annotation().Ziel(), Seite-1), view);
 	Pg1->setMinimumSize(QSize(Pg1->pmx.width(), Pg1->pmx.height()));
 	GroupBox11Layout->addMultiCellWidget(Pg1, 1, 3, 2, 2);
 	TextLabel41 = new QLabel( GroupBox11, "TextLabel4" );
@@ -658,6 +662,12 @@ Annot::Annot(QWidget* parent, PageItem *it, int Seite, int b, int h, ColorList F
 			Breite = Pg1->Breite;
 			Hoehe = Pg1->Hoehe;
 		}
+		else
+		{
+			Destfile->setEnabled(false);
+			ChFile->setEnabled(false);
+			LExtern->setChecked(false);
+		}
 	}
 
 	tab4 = new QWidget( TabWidget2, "privateWidget" );
@@ -1195,7 +1205,7 @@ void Annot::GetNIcon()
 	QString fileName;
 	QString wdir = dirs->get("icon", ".");
 	CustomFDialog dia(this, wdir, tr("Open"),
-	                  tr("Images (*.tif *.png *.jpg *.xpm);;PostScript (*.eps);;All Files (*)"), "", true);
+	                  tr("Images (*.tif *.png *.jpg *.xpm);;PostScript (*.eps *.epsi);;All Files (*)"), fdShowPreview | fdExistingFiles);
 	if (dia.exec() == QDialog::Accepted)
 		fileName = dia.selectedFile();
 	else
@@ -1204,15 +1214,14 @@ void Annot::GetNIcon()
 	{
 		dirs->set("icon", fileName.left(fileName.findRev("/")));
 		QPixmap pmI1;
-		ScImage im;
-		im.LoadPicture(fileName, "", 0, false, false, 1, 72);
-		pmI1.convertFromImage(im);
+		CMSettings cms(view->Doc, "", 0);
+		item->pixm.LoadPicture(fileName, cms, false, false, ScImage::RGBData, 72);
+		pmI1.convertFromImage(item->pixm.qImage());
 		NiconPrev->setPixmap(pmI1);
 		item->Pfile = fileName;
 		item->PicAvail = true;
-		item->pixm = im.copy();
-		int w = im.width();
-		int h = im.height();
+		int w = item->pixm.width();
+		int h = item->pixm.height();
 		double sw = item->width() / w;
 		double sh = item->height() / h;
 		double sc = QMIN(sw,sh);
@@ -1227,7 +1236,7 @@ void Annot::GetPIcon()
 	QString fileName;
 	QString wdir = dirs->get("icon", ".");
 	CustomFDialog dia(this, wdir, tr("Open"),
-	                  tr("Images (*.tif *.png *.jpg *.xpm);;PostScript (*.eps);;All Files (*)"), "", true);
+	                  tr("Images (*.tif *.png *.jpg *.xpm);;PostScript (*.eps *.epsi);;All Files (*)"), fdShowPreview | fdExistingFiles);
 	if (dia.exec() == QDialog::Accepted)
 		fileName = dia.selectedFile();
 	else
@@ -1237,8 +1246,9 @@ void Annot::GetPIcon()
 		dirs->set("icon", fileName.left(fileName.findRev("/")));
 		QPixmap pmI1;
 		ScImage im;
-		im.LoadPicture(fileName, "", 0, false, false, 1, 72);
-		pmI1.convertFromImage(im);
+		CMSettings cms(view->Doc, "",0 );
+		im.LoadPicture(fileName, cms, false, false, ScImage::RGBData, 72);
+		pmI1.convertFromImage(im.qImage());
 		PiconPrev->setPixmap(pmI1);
 		item->Pfile2 = fileName;
 		IconPR->setEnabled(true);
@@ -1250,7 +1260,7 @@ void Annot::GetRIcon()
 	QString fileName;
 	QString wdir = dirs->get("icon", ".");
 	CustomFDialog dia(this, wdir, tr("Open"),
-	                  tr("Images (*.tif *.png *.jpg *.xpm);;PostScript (*.eps);;All Files (*)"), "", true);
+	                  tr("Images (*.tif *.png *.jpg *.xpm);;PostScript (*.eps *.epsi);;All Files (*)"), fdShowPreview | fdExistingFiles);
 	if (dia.exec() == QDialog::Accepted)
 		fileName = dia.selectedFile();
 	else
@@ -1260,8 +1270,9 @@ void Annot::GetRIcon()
 		dirs->set("icon", fileName.left(fileName.findRev("/")));
 		QPixmap pmI1;
 		ScImage im;
-		im.LoadPicture(fileName, "", 0, false, false, 1, 72);
-		pmI1.convertFromImage(im);
+		CMSettings cms(view->Doc, "", 0);
+		im.LoadPicture(fileName, cms, false, false, ScImage::RGBData, 72);
+		pmI1.convertFromImage(im.qImage());
 		RiconPrev->setPixmap(pmI1);
 		item->Pfile3 = fileName;
 		IconRR->setEnabled(true);
@@ -1480,7 +1491,7 @@ void Annot::DecodeNum()
 		}
 	if (item->annotation().Format() == 3)
 		{
-		Format0c->setCurrentText(pfol[0]);
+		Format0c->setCurrentText(pfol[0].remove("\""));
 		setDateSample(pfol[0]);
 		}
 	if (item->annotation().Format() == 4)
@@ -1635,8 +1646,10 @@ void Annot::SetFoScript(int it)
 	{
 		EditFormat->setEnabled( true );
 		EditKeystr->setEnabled( true );
-		KeyScript->setText( item->annotation().K_act() );
-		FormatScript->setText( item->annotation().F_act() );
+		KeyScript->setText("");
+		FormatScript->setText("");
+//		KeyScript->setText( item->annotation().K_act() );
+//		FormatScript->setText( item->annotation().F_act() );
 	}
 	item->annotation().setFormat(it);
 }
@@ -1663,8 +1676,8 @@ void Annot::SetPg(int v)
 	}
 	else
 	{
-		Pg1->SetSeite(v-1, 100);
-		SpinBox11->setValue(v);
+		Pg1->SetSeite(QMIN(v-1, MaxSeite-1), 100);
+		SpinBox11->setValue(QMIN(v, MaxSeite));
 		Breite = OriBreite;
 		Hoehe = OriHoehe;
 		//		SetCo(0,0);
@@ -1686,7 +1699,7 @@ void Annot::SetCross()
 
 void Annot::SetVals()
 {
-	QString tmp;
+	QString tmp, tmp2;
 	QString Nfo("");
 	bool AAct = false;
 	item->annotation().setType(ComboBox1->currentItem()+2);
@@ -1707,7 +1720,7 @@ void Annot::SetVals()
 	item->annotation().setIsChk(isChkd->isChecked());
 	item->annotation().setChkStil(ChkStil->currentItem());
 	item->annotation().setBorderColor(BorderC->currentText());
-	if (item->annotation().borderColor() == CommonStrings::NoneColor)
+	if (item->annotation().borderColor() == CommonStrings::tr_NoneColor)
 		item->annotation().setBorderColor(CommonStrings::None);
 	Limit->isChecked() ? item->annotation().setMaxChar(MaxChars->value()) : item->annotation().setMaxChar(-1);
 	if (item->annotation().Type() == 2)
@@ -1797,7 +1810,7 @@ void Annot::SetVals()
 				item->annotation().setK_act("");
 				break;
 			case 1:
-				Nfo = tmp.setNum(Decim->value())+", "+tmp.setNum(FormNum)+", 0, 0, \"";
+				Nfo = tmp.setNum(Decim->value())+", "+tmp2.setNum(FormNum)+", 0, 0, \"";
 				if (UseCurr->isChecked())
 					{
 					if (!PreCurr->isChecked())
@@ -1879,7 +1892,7 @@ void Annot::SetVals()
 				item->annotation().setActionType(2);
 			}
 			item->annotation().setZiel(SpinBox11->value()-1);
-			item->annotation().setAction(tmp.setNum(SpinBox21->value())+" "+tmp.setNum(Hoehe-SpinBox31->value())+" 0");
+			item->annotation().setAction(tmp.setNum(SpinBox21->value())+" "+tmp2.setNum(Hoehe-SpinBox31->value())+" 0");
 			break;
 		case 3:
 			item->annotation().setActionType(3);
