@@ -16,10 +16,13 @@ for which a new license (GPL+exception) is in place.
 
 #include "colorcombo.h"
 #include "commonstrings.h"
+#include "prefsmanager.h"
+#include "prefscontext.h"
+#include "prefsfile.h"
 #include "scribusdoc.h"
 #include "styleselect.h"
-#include "scribusdoc.h"
 #include "scribusstructs.h"
+#include "sctextstruct.h"
 #include "scpaths.h"
 #include "scribus.h"
 #include "util.h"
@@ -28,8 +31,8 @@ for which a new license (GPL+exception) is in place.
 #include "sampleitem.h"
 
 
-EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<ParagraphStyle> v, bool neu, double au, int dEin, ScribusDoc *doc)
-		: QDialog( parent, "EditST", true, 0)
+EditStyle::EditStyle( QWidget* parent, ParagraphStyle *vor, const StyleSet<ParagraphStyle>& v, bool neu, double au, int dEin, ScribusDoc *doc)
+		: QDialog( parent, "EditST", true, 0), allV(v)
 {
 	qApp->setOverrideCursor(QCursor(waitCursor));
 	parentDoc = doc;
@@ -38,10 +41,19 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	AutoVal = au;
 	DocsEin = dEin;
 
-	sampleItem = new SampleItem();
+	sampleItem = new SampleItem(doc);
 	sampleItem->setLoremIpsum(2);
 	sampleItem->cleanupTemporary();
 
+	prefs = PrefsManager::instance()->prefsFile->getContext("edit_style");
+	QString prevBg = prefs->get("PreviewBg", "");
+	if( !prevBg.isEmpty() )
+	{
+		QColor bg(prevBg);
+		sampleItem->setBgColorMngt(false);
+		sampleItem->setBgColor(bg);
+	}
+
 	EditStyleLayout = new QVBoxLayout( this, 10, 5, "EditStyleLayout");
 
 	TextLabel1 = new QLabel( tr( "&Name:" ), this, "TextLabel1" );
@@ -49,8 +61,8 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 
 	Name = new QLineEdit( this, "Name" );
 	Name->setMinimumSize( QSize( 200, 22 ) );
-	Name->setText( vor->Vname );
-	OldName = vor->Vname;
+	Name->setText( vor->name() );
+	OldName = vor->name();
 	IsNew = neu;
 	TextLabel1->setBuddy(Name);
 	EditStyleLayout->addWidget( Name );
@@ -64,13 +76,13 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	GroupFontLayout = new QVBoxLayout( GroupFont->layout() );
 	GroupFontLayout->setAlignment( Qt::AlignLeft );
 	FontC = new FontComboH(GroupFont);
-	FontC->setCurrentFont(vor->Font);
+	FontC->setCurrentFont(vor->charStyle().font().scName());
 	GroupFontLayout->addWidget( FontC );
 	layout7 = new QHBoxLayout( 0, 0, 5, "layout7");
 	SizeC = new MSpinBox( 1, 2048, GroupFont, 1 );
 	SizeC->setMinimumSize( QSize( 70, 22 ) );
 	SizeC->setSuffix( tr( " pt" ) );
-	SizeC->setValue(vor->FontSize / 10.0);
+	SizeC->setValue(vor->charStyle().fontSize() / 10.0);
 	TextF2 = new QLabel( "" ,GroupFont, "TextF2" );
 	TextF2->setPixmap(loadIcon("Zeichen.xpm"));
 	TextF2->setMinimumSize( QSize( 22, 22 ) );
@@ -83,7 +95,7 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	pixmapLabel3->setPixmap( loadIcon("textscaleh.png") );
 	layout7->addWidget( pixmapLabel3 );
 	fontHScale = new MSpinBox( 10, 400, GroupFont, 1 );
-	fontHScale->setValue( vor->scaleH / 10.0 );
+	fontHScale->setValue( vor->charStyle().scaleH() / 10.0 );
 	fontHScale->setSuffix( tr( " %" ) );
 	layout7->addWidget( fontHScale );
 	pixmapLabel3_2 = new QLabel( "", GroupFont, "pixmapLabel3_2" );
@@ -93,21 +105,21 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	layout7->addWidget( pixmapLabel3_2 );
 
 	fontVScale = new MSpinBox( 10, 400, GroupFont, 1 );
-	fontVScale->setValue( vor->scaleV / 10.0 );
+	fontVScale->setValue( vor->charStyle().scaleV() / 10.0 );
 	fontVScale->setSuffix( tr( " %" ) );
 	layout7->addWidget( fontVScale );
 	GroupFontLayout->addLayout( layout7 );
 
 	layout9a = new QHBoxLayout( 0, 0, 0, "layout9");
 	EffeS = new StyleSelect(GroupFont);
-	EffeS->setStyle(vor->FontEffect);
-	EffeS->ShadowVal->Xoffset->setValue(vor->txtShadowX / 10.0);
-	EffeS->ShadowVal->Yoffset->setValue(vor->txtShadowY / 10.0);
-	EffeS->OutlineVal->LWidth->setValue(vor->txtOutline / 10.0);
-	EffeS->UnderlineVal->LPos->setValue(vor->txtUnderPos / 10.0);
-	EffeS->UnderlineVal->LWidth->setValue(vor->txtUnderWidth / 10.0);
-	EffeS->StrikeVal->LPos->setValue(vor->txtStrikePos / 10.0);
-	EffeS->StrikeVal->LWidth->setValue(vor->txtStrikeWidth / 10.0);
+	EffeS->setStyle(vor->charStyle().effects());
+	EffeS->ShadowVal->Xoffset->setValue(vor->charStyle().shadowXOffset() / 10.0);
+	EffeS->ShadowVal->Yoffset->setValue(vor->charStyle().shadowYOffset() / 10.0);
+	EffeS->OutlineVal->LWidth->setValue(vor->charStyle().outlineWidth() / 10.0);
+	EffeS->UnderlineVal->LPos->setValue(vor->charStyle().underlineOffset() / 10.0);
+	EffeS->UnderlineVal->LWidth->setValue(vor->charStyle().underlineWidth() / 10.0);
+	EffeS->StrikeVal->LPos->setValue(vor->charStyle().strikethruOffset() / 10.0);
+	EffeS->StrikeVal->LWidth->setValue(vor->charStyle().strikethruWidth() / 10.0);
 	layout9a->addWidget( EffeS );
 	QSpacerItem* spacer1 = new QSpacerItem( 0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum );
 	layout9a->addItem( spacer1 );
@@ -115,7 +127,7 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 
 	layout9b = new QHBoxLayout( 0, 0, 0, "layout9");
 	AligS = new AlignSelect(GroupFont);
-	AligS->setStyle(vor->textAlignment);
+	AligS->setStyle(vor->alignment());
 	layout9b->addWidget( AligS );
 	QSpacerItem* spacer2 = new QSpacerItem( 0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum );
 	layout9a->addItem( spacer2 );
@@ -123,7 +135,7 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 
 	layout5 = new QHBoxLayout( 0, 0, 5, "layout5");
 	FillIcon = new QLabel( "", GroupFont, "FillIcon" );
-	FillIcon->setPixmap(loadIcon("fill.png"));
+	FillIcon->setPixmap(loadIcon("16/color-fill.png"));
 	layout5->addWidget( FillIcon );
 	TxFill = new ColorCombo( false, GroupFont, "TxFill" );
 	layout5->addWidget( TxFill );
@@ -140,7 +152,7 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 
 	layout6 = new QHBoxLayout( 0, 0, 5, "layout6");
 	StrokeIcon = new QLabel( "", GroupFont, "StrokeIcon" );
-	StrokeIcon->setPixmap(loadIcon("Stiftalt.xpm"));
+	StrokeIcon->setPixmap(loadIcon("16/color-stroke.png"));
 	layout6->addWidget( StrokeIcon );
 	TxStroke = new ColorCombo( false, GroupFont, "TxStroke" );
 	layout6->addWidget( TxStroke );
@@ -159,20 +171,20 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	TxStroke->clear();
 	ColorList::Iterator it;
 	QPixmap pm = QPixmap(15, 15);
-	TxFill->insertItem(CommonStrings::NoneColor);
-	TxStroke->insertItem(CommonStrings::NoneColor);
+	TxFill->insertItem(CommonStrings::tr_NoneColor);
+	TxStroke->insertItem(CommonStrings::tr_NoneColor);
 	for (it = doc->PageColors.begin(); it != doc->PageColors.end(); ++it)
 	{
-		TxFill->insertSmallItem(doc->PageColors[it.key()], it.key());
-		TxStroke->insertSmallItem(doc->PageColors[it.key()], it.key());
+		TxFill->insertSmallItem(it.data(), parentDoc, it.key());
+		TxStroke->insertSmallItem(it.data(), parentDoc, it.key());
 	}
 	StrokeIcon->setEnabled(false);
 	PM1->setEnabled(false);
 	TxStroke->setEnabled(false);
-	TxFill->setCurrentText(vor->FColor);
-	TxStroke->setCurrentText(vor->SColor);
-	PM2->setValue(vor->FShade);
-	PM1->setValue(vor->SShade);
+	TxFill->setCurrentText(vor->charStyle().fillColor());
+	TxStroke->setCurrentText(vor->charStyle().strokeColor());
+	PM2->setValue(vor->charStyle().fillShade());
+	PM1->setValue(vor->charStyle().strokeShade());
 
 	layout9->addWidget( GroupFont );
 
@@ -198,7 +210,7 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	AbstandVLayout->addWidget( linespacingButton, 0, 0 );
 	LineSpVal = new MSpinBox( 1, 300, AbstandV, 1 );
 	LineSpVal->setSuffix( tr( " pt" ) );
-	LineSpVal->setValue(vor->LineSpa);
+	LineSpVal->setValue(vor->lineSpacing());
 	AbstandVLayout->addWidget( LineSpVal, 0, 1 );
 	pixmapLabel2 = new QLabel( AbstandV, "pixmapLabel2" );
 	pixmapLabel2->setMinimumSize( QSize( 22, 22 ) );
@@ -206,7 +218,7 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	pixmapLabel2->setPixmap( loadIcon("textbase.png") );
 	AbstandVLayout->addWidget( pixmapLabel2, 0, 2 );
 	fontBase = new MSpinBox( -100, 100, AbstandV, 1 );
-	fontBase->setValue( vor->baseOff / 10.0 );
+	fontBase->setValue( vor->charStyle().baselineOffset() / 10.0 );
 	fontBase->setSuffix( tr( " %" ) );
 	AbstandVLayout->addWidget( fontBase, 0, 3 );
 	pixmapLabel3_3 = new QLabel( AbstandV, "pixmapLabel3_3" );
@@ -215,7 +227,7 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	pixmapLabel3_3->setPixmap( loadIcon("textkern.png") );
 	AbstandVLayout->addWidget( pixmapLabel3_3, 0, 4 );
 	fontKern = new MSpinBox( -300, 300, AbstandV, 1 );
-	fontKern->setValue( vor->kernVal / 10.0 );
+	fontKern->setValue( vor->charStyle().tracking() / 10.0 );
 	fontKern->setSuffix( tr( " %" ) );
 	AbstandVLayout->addWidget( fontKern, 0, 5 );
 
@@ -244,17 +256,17 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	DropLines = new QSpinBox( DropCaps, "DropLines" );
 	DropLines->setMinValue( 2 );
 	DropLines->setMaxValue( 20 );
-	DropLines->setValue(vor->DropLin);
+	DropLines->setValue(vor->dropCapLines());
 	CapLabel = new QLabel( DropLines, tr("&Lines:"), DropCaps, "CapLabel" );
 	DropCapsLayout->addWidget( CapLabel, 0, 0 );
 	DropCapsLayout->addWidget( DropLines, 0, 1 );
 	DropDist = new MSpinBox( -3000, 3000, DropCaps, 1);
 	DropDist->setSuffix( tr( " pt" ) );
-	DropDist->setValue(vor->DropDist);
+	DropDist->setValue(vor->dropCapOffset());
 	CapLabel2 = new QLabel( DropLines, tr("Distance from Text:"), DropCaps, "CapLabel2" );
 	DropCapsLayout->addWidget( CapLabel2, 1, 0 );
 	DropCapsLayout->addWidget( DropDist, 1, 1 );
-	DropCaps->setChecked(vor->Drop);
+	DropCaps->setChecked(vor->hasDropCap());
 	layout8->addWidget( DropCaps );
 	layout9->addLayout( layout8 );
 	EditStyleLayout->addLayout( layout9 );
@@ -263,15 +275,15 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	{
 		lineSpacingPop->setItemChecked(lineSpacingPop->idAt(al), false);
 	}
-	if (vor->BaseAdj)
+	if (vor->useBaselineGrid())
 	{
 		LineSpVal->setEnabled(false);
 		lineSpacingPop->setItemChecked(lineSpacingPop->idAt(2), true);
 	}
 	else
 	{
-		lineSpacingPop->setItemChecked(lineSpacingPop->idAt(vor->LineSpaMode), true);
-		if (vor->LineSpaMode > 0)
+		lineSpacingPop->setItemChecked(lineSpacingPop->idAt(vor->lineSpacingMode()), true);
+		if (vor->lineSpacingMode() > 0)
 			LineSpVal->setEnabled(false);
 		else
 			LineSpVal->setEnabled(true);
@@ -285,10 +297,10 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	GroupBox10Layout->setAlignment( Qt::AlignTop );
 	GroupBox10Layout->setSpacing( 5 );
 	GroupBox10Layout->setMargin( 10 );
-	TabList = new Tabruler(GroupBox10, true, DocsEin, vor->TabValues, -1);
-	TabList->setLeftIndentData(vor->Indent);
+	TabList = new Tabruler(GroupBox10, true, DocsEin, vor->tabValues(), -1);
+	TabList->setLeftIndentData(vor->leftMargin());
 	TabList->setLeftIndent();
-	TabList->setFirstLineData(vor->First);
+	TabList->setFirstLineData(vor->firstIndent());
 	TabList->setFirstLine();
 	GroupBox10Layout->addWidget( TabList );
 	EditStyleLayout->addWidget( GroupBox10 );
@@ -305,7 +317,7 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	previewCaption->setChecked(PrefsManager::instance()->appPrefs.haveStylePreview);
 	QSpacerItem* spacerBg = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
 	previewBgColor = new QPushButton(this, "previewBgColor");
-	previewBgColor->setText(tr("Background"));
+	previewBgColor->setText( tr("Background"));
 	layoutPrevSet->addWidget(previewCaption);
 	layoutPrevSet->addItem(spacerBg);
 	layoutPrevSet->addWidget(previewBgColor);
@@ -335,9 +347,8 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	EditStyleLayout->addLayout(Layout17);
 
 	werte = vor;
-	allV = v;
 	// tooltips
-	QToolTip::add(previewBgColor, "<qt>" + tr("Select for easier reading of light coloured text styles") + "</qt>");
+	QToolTip::add(previewBgColor, "<qt>" + tr("Select for easier reading of light colored text styles") + "</qt>");
 	QToolTip::add( Name, "<qt>" + tr( "Name of your paragraph style" ) + "</qt>" );
 	QToolTip::add( FontC, "<qt>" + tr( "Font of selected text or object" ) + "</qt>" );
 	QToolTip::add( SizeC, "<qt>" + tr( "Font Size" ) + "</qt>" );
@@ -404,9 +415,9 @@ EditStyle::EditStyle( QWidget* parent, struct ParagraphStyle *vor, QValueList<Pa
 	AboveV->setSuffix(ein);
 	BelowV->setSuffix(ein);
 	DropDist->setSuffix(ein);
-	BelowV->setValue(vor->gapAfter * parentDoc->unitRatio());
-	AboveV->setValue(vor->gapBefore * parentDoc->unitRatio());
-	DropDist->setValue(vor->DropDist * parentDoc->unitRatio());
+	BelowV->setValue(vor->gapAfter() * parentDoc->unitRatio());
+	AboveV->setValue(vor->gapBefore() * parentDoc->unitRatio());
+	DropDist->setValue(vor->dropCapOffset() * parentDoc->unitRatio());
 	ColorChange();
 	togglePreview();
 	qApp->restoreOverrideCursor();
@@ -425,9 +436,20 @@ void EditStyle::toggleLsp(int id)
 	}
 	lineSpacingPop->setItemChecked(id, true);
 	if (lineSpacingPop->indexOf(id) > 0)
+	{
+		LineSpVal->setSpecialValueText( tr( "Auto" ) );
+		LineSpVal->setMinValue(0);
+		LineSpVal->setValue(0);
 		LineSpVal->setEnabled(false);
+	}
 	else
+	{
 		LineSpVal->setEnabled(true);
+		LineSpVal->setSpecialValueText("");
+		LineSpVal->setMinValue(1);
+		double val = SizeC->value();
+		LineSpVal->setValue((val  * AutoVal / 100) + val);
+	}
 	updatePreview();
 }
 
@@ -468,7 +490,8 @@ void EditStyle::ColorChange()
 void EditStyle::FontChange()
 {
 	double val = SizeC->value();
-	LineSpVal->setValue((val  * AutoVal / 100) + val);
+	if (LineSpVal->isEnabled())
+		LineSpVal->setValue((val  * AutoVal / 100) + val);
 	updatePreview();
 }
 
@@ -479,7 +502,7 @@ void EditStyle::Verlassen()
 	{
 		for (uint x=0; x<allV.count()-1; ++x)
 		{
-			if (Name->text() == allV[x].Vname)
+			if (Name->text() == allV[x].name())
 			{
 				QMessageBox::information(this, CommonStrings::trWarning, mess, CommonStrings::tr_OK,0, 0, 0, QMessageBox::Ok);
 				Name->selectAll();
@@ -494,7 +517,7 @@ void EditStyle::Verlassen()
 		{
 			for (uint x=0; x<allV.count(); ++x)
 			{
-				if (Name->text() == allV[x].Vname)
+				if (Name->text() == allV[x].name())
 				{
 					QMessageBox::information(this, CommonStrings::trWarning, mess, CommonStrings::tr_OK,0, 0, 0, QMessageBox::Ok);
 					Name->selectAll();
@@ -504,50 +527,55 @@ void EditStyle::Verlassen()
 			}
 		}
 	}
-	werte->FontEffect = EffeS->getStyle();
-	werte->textAlignment = AligS->getStyle();
+	copyStyleSettings(*werte);
+	accept();
+}
+
+void EditStyle::copyStyleSettings(ParagraphStyle& parstyle)
+{
+	CharStyle charstyle;
+	charstyle.setFeatures(static_cast<StyleFlag>(EffeS->getStyle()).featureList());
+	parstyle.setAlignment(static_cast<ParagraphStyle::AlignmentType>(AligS->getStyle()));
 	for (uint al = 0; al < lineSpacingPop->count(); ++al)
 	{
 		if (lineSpacingPop->isItemChecked(lineSpacingPop->idAt(al)))
 		{
-			werte->LineSpaMode = al;
-			if (al == 2)
-				werte->BaseAdj = true;
-			else
-				werte->BaseAdj = false;
+			parstyle.setLineSpacingMode(static_cast<ParagraphStyle::LineSpacingMode>(al));
+			parstyle.setUseBaselineGrid(al == 2);
 			break;
 		}
 	}
-	werte->LineSpa = LineSpVal->value();
-	werte->Indent = QMAX(TabList->getLeftIndent(), 0.0);
-	werte->First = TabList->getFirstLine();
-	werte->gapBefore = AboveV->value() / parentDoc->unitRatio();
-	werte->gapAfter = BelowV->value() / parentDoc->unitRatio();
-	werte->Vname = Name->text();
-	werte->Font = FontC->currentFont();
-	werte->FontSize = qRound(SizeC->value() * 10.0);
-	werte->Drop = DropCaps->isChecked();
-	werte->DropLin = DropLines->value();
-	werte->DropDist = DropDist->value() / parentDoc->unitRatio();
-	werte->FColor = TxFill->currentText();
-	werte->FShade = PM2->getValue();
-	werte->SColor = TxStroke->currentText();
-	werte->SShade = PM1->getValue();
-	werte->TabValues = TabList->getTabVals();
-	werte->txtShadowX = qRound(EffeS->ShadowVal->Xoffset->value() * 10.0);
-	werte->txtShadowY = qRound(EffeS->ShadowVal->Yoffset->value() * 10.0);
-	werte->txtOutline = qRound(EffeS->OutlineVal->LWidth->value() * 10.0);
-	werte->txtStrikePos = qRound(EffeS->StrikeVal->LPos->value() * 10.0);
-	werte->txtStrikeWidth = qRound(EffeS->StrikeVal->LWidth->value() * 10.0);
-	werte->txtUnderPos = qRound(EffeS->UnderlineVal->LPos->value() * 10.0);
-	werte->txtUnderWidth = qRound(EffeS->UnderlineVal->LWidth->value() * 10.0);
-	werte->scaleH = qRound(fontHScale->value() * 10.0);
-	werte->scaleV = qRound(fontVScale->value() * 10.0);
-	werte->baseOff = qRound(fontBase->value() * 10.0);
-	werte->kernVal = qRound(fontKern->value() * 10.0);
-	accept();
+	parstyle.setLineSpacing(LineSpVal->value());
+	parstyle.setLeftMargin(QMAX(TabList->getLeftIndent(), 0.0));
+	parstyle.setFirstIndent(TabList->getFirstLine());
+	parstyle.setGapBefore(AboveV->value() / parentDoc->unitRatio());
+	parstyle.setGapAfter(BelowV->value() / parentDoc->unitRatio());
+	parstyle.setName(Name->text());
+	charstyle.setFont(PrefsManager::instance()->appPrefs.AvailFonts[FontC->currentFont()]);
+	charstyle.setFontSize(qRound(SizeC->value() * 10.0));
+	parstyle.setHasDropCap(DropCaps->isChecked());
+	parstyle.setDropCapLines(DropLines->value());
+	parstyle.setDropCapOffset(DropDist->value() / parentDoc->unitRatio());
+	charstyle.setFillColor(TxFill->currentText());
+	charstyle.setFillShade(PM2->getValue());
+	charstyle.setStrokeColor(TxStroke->currentText());
+	charstyle.setStrokeShade(PM1->getValue());
+	parstyle.setTabValues(TabList->getTabVals());
+	charstyle.setShadowXOffset(qRound(EffeS->ShadowVal->Xoffset->value() * 10.0));
+	charstyle.setShadowYOffset(qRound(EffeS->ShadowVal->Yoffset->value() * 10.0));
+	charstyle.setOutlineWidth(qRound(EffeS->OutlineVal->LWidth->value() * 10.0));
+	charstyle.setStrikethruOffset(qRound(EffeS->StrikeVal->LPos->value() * 10.0));
+	charstyle.setStrikethruWidth(qRound(EffeS->StrikeVal->LWidth->value() * 10.0));
+	charstyle.setUnderlineOffset(qRound(EffeS->UnderlineVal->LPos->value() * 10.0));
+	charstyle.setUnderlineWidth(qRound(EffeS->UnderlineVal->LWidth->value() * 10.0));
+	charstyle.setScaleH(qRound(fontHScale->value() * 10.0));
+	charstyle.setScaleV(qRound(fontVScale->value() * 10.0));
+	charstyle.setBaselineOffset(qRound(fontBase->value() * 10.0));
+	charstyle.setTracking(qRound(fontKern->value() * 10.0));
+	parstyle.charStyle().applyCharStyle(charstyle);
 }
 
+
 void EditStyle::updatePreview()
 {
 	if (!previewCaption->isChecked())
@@ -555,47 +583,8 @@ void EditStyle::updatePreview()
 	qApp->setOverrideCursor(QCursor(waitCursor));
 
 	ParagraphStyle tmpStyle;
-	tmpStyle.Vname = Name->text() + " (preview temporary)";
-	tmpStyle.FontEffect = EffeS->getStyle();
-	tmpStyle.textAlignment = AligS->getStyle();
-	for (uint al = 0; al < lineSpacingPop->count(); ++al)
-	{
-		if (lineSpacingPop->isItemChecked(lineSpacingPop->idAt(al)))
-		{
-			tmpStyle.LineSpaMode = al;
-			if (al == 2)
-				tmpStyle.BaseAdj = true;
-			else
-				tmpStyle.BaseAdj = false;
-			break;
-		}
-	}
-	tmpStyle.LineSpa = LineSpVal->value();
-	tmpStyle.Indent = TabList->getLeftIndent();
-	tmpStyle.First = TabList->getFirstLine();
-	tmpStyle.gapBefore = AboveV->value() / parentDoc->unitRatio();
-	tmpStyle.gapAfter = BelowV->value() / parentDoc->unitRatio();
-	tmpStyle.Font = FontC->currentFont();
-	tmpStyle.FontSize = qRound(SizeC->value() * 10.0);
-	tmpStyle.Drop = DropCaps->isChecked();
-	tmpStyle.DropLin = DropLines->value();
-	tmpStyle.DropDist = DropDist->value() / parentDoc->unitRatio();
-	tmpStyle.FColor = TxFill->currentText();
-	tmpStyle.FShade = PM2->getValue();
-	tmpStyle.SColor = TxStroke->currentText();
-	tmpStyle.SShade = PM1->getValue();
-	tmpStyle.TabValues = TabList->getTabVals();
-	tmpStyle.txtShadowX = qRound(EffeS->ShadowVal->Xoffset->value() * 10.0);
-	tmpStyle.txtShadowY = qRound(EffeS->ShadowVal->Yoffset->value() * 10.0);
-	tmpStyle.txtOutline = qRound(EffeS->OutlineVal->LWidth->value() * 10.0);
-	tmpStyle.txtStrikePos = qRound(EffeS->StrikeVal->LPos->value() * 10.0);
-	tmpStyle.txtStrikeWidth = qRound(EffeS->StrikeVal->LWidth->value() * 10.0);
-	tmpStyle.txtUnderPos = qRound(EffeS->UnderlineVal->LPos->value() * 10.0);
-	tmpStyle.txtUnderWidth = qRound(EffeS->UnderlineVal->LWidth->value() * 10.0);
-	tmpStyle.scaleH = qRound(fontHScale->value() * 10.0);
-	tmpStyle.scaleV = qRound(fontVScale->value() * 10.0);
-	tmpStyle.baseOff = qRound(fontBase->value() * 10.0);
-	tmpStyle.kernVal = qRound(fontKern->value() * 10.0);
+	copyStyleSettings(tmpStyle);
+	tmpStyle.setName(Name->text() + " (preview temporary)");
 	sampleItem->setStyle(tmpStyle);
 	QPixmap pm = sampleItem->getSample(previewText->width(), previewText->height());
 	previewText->setPixmap(pm);
@@ -608,7 +597,9 @@ void EditStyle::setPreviewBackground()
 	bg = QColorDialog::getColor(previewText->paletteBackgroundColor(), this);
 	if (bg.isValid())
 	{
+		prefs->set("PreviewBg", bg.name());
 		previewText->setPaletteBackgroundColor(bg);
+		sampleItem->setBgColorMngt(false);
 		sampleItem->setBgColor(bg);
 		updatePreview();
 	}
