@@ -27,6 +27,7 @@ for which a new license (GPL+exception) is in place.
 #include "undomanager.h"
 #include "undostate.h"
 #include "frameedit.h"
+#include "guidemanager.h"
 
 extern QPixmap loadIcon(QString nam);
 
@@ -37,9 +38,6 @@ Page::Page(const double x, const double y, const double b, const double h) :
 	initialMargins(40,40,40,40),
 	LeftPg(0),
 	MPageNam(""),
-	PageNam(""),
-	XGuides(),
-	YGuides(),
 	FromMaster(),
 	undoManager(UndoManager::instance()),
 	m_xOffset(x),
@@ -48,8 +46,10 @@ Page::Page(const double x, const double y, const double b, const double h) :
 	m_height(h),
 	m_initialWidth(b),
 	m_initialHeight(h),
+	m_PageName(""),
 	m_Doc(NULL)
 {
+	guides.setPage(this);
 }
 
 Page::~Page()
@@ -74,135 +74,15 @@ void Page::setDocument(ScribusDoc *doc)
 void Page::setPageNr(int pageNr)
 {
 	m_pageNr = pageNr;
-	if (PageNam.isEmpty())
-		setUName(QString(QObject::tr("Page") + " %1").arg(ScMW->doc->FirstPnum + m_pageNr));
+	if (m_PageName.isEmpty())
+		setUName(QString(QObject::tr("Page") + " %1").arg(m_Doc->FirstPnum + m_pageNr));
 	else
-		setUName(PageNam);
-}
-
-void Page::addXGuide(double position)
-{
-	XGuides.append(position);
-	qHeapSort(XGuides);
-	if (UndoManager::undoEnabled())
-	{
-		SimpleState* ss = new SimpleState(Um::AddVGuide, 0, Um::IGuides);
-		ss->set("ADD_V", position);
-		undoManager->action(this, ss);
-	}
-}
-
-void Page::addYGuide(double position)
-{
-	YGuides.append(position);
-	qHeapSort(YGuides);
-	if (UndoManager::undoEnabled())
-	{
-		SimpleState* ss = new SimpleState(Um::AddHGuide, 0, Um::IGuides);
-		ss->set("ADD_H", position);
-		undoManager->action(this, ss);
-	}
-}
-
-void Page::addXGuides(QValueList<double>& guides)
-{
-	QValueList<double> toBeRemoved;
-	for (uint i = 0; i < XGuides.size(); ++i)
-		if (guides.find(XGuides[i]) == guides.end())
-			toBeRemoved.push_back(XGuides[i]);
-
-	for (uint i = 0; i < toBeRemoved.size(); ++i)
-		removeXGuide(toBeRemoved[i]);
-
-	for (uint i = 0; i < guides.size(); ++i)
-		if (XGuides.find(guides[i]) == XGuides.end())
-			addXGuide(guides[i]);
-}
-
-void Page::addYGuides(QValueList<double>& guides)
-{
-	QValueList<double> toBeRemoved;
-	for (uint i = 0; i < YGuides.size(); ++i)
-		if (guides.find(YGuides[i]) == guides.end())
-			toBeRemoved.push_back(YGuides[i]);
-
-	for (uint i = 0; i < toBeRemoved.size(); ++i)
-		removeYGuide(toBeRemoved[i]);
-
-	for (uint i = 0; i < guides.size(); ++i)
-		if (YGuides.find(guides[i]) == YGuides.end())
-			addYGuide(guides[i]);
-}
-
-void Page::removeXGuide(double position)
-{
-	XGuides.remove(XGuides.find(position));
-	if (UndoManager::undoEnabled())
-	{
-		SimpleState* ss = new SimpleState(Um::DelVGuide, 0, Um::IGuides);
-		ss->set("REMOVE_V", position);
-		undoManager->action(this, ss);
-	}
-}
-
-void Page::removeXGuide(int index)
-{
-	double position = XGuides[index];
-	removeXGuide(position);
-}
-
-void Page::removeYGuide(double position)
-{
-	YGuides.remove(YGuides.find(position));
-	if (UndoManager::undoEnabled())
-	{
-		SimpleState* ss = new SimpleState(Um::DelHGuide, 0, Um::IGuides);
-		ss->set("REMOVE_H", position);
-		undoManager->action(this, ss);
-	}
-}
-
-void Page::removeYGuide(int index)
-{
-	double position = YGuides[index];
-	removeYGuide(position);
-}
-
-void Page::moveXGuide(int fromIndex, double to)
-{
-	double from = XGuides[fromIndex];
-	undoManager->setUndoEnabled(false);
-	removeXGuide(from);
-	addXGuide(to);
-	undoManager->setUndoEnabled(true);
-	if (UndoManager::undoEnabled())
-	{
-		SimpleState* ss = new SimpleState(Um::MoveVGuide, 0, Um::IGuides);
-		ss->set("MOVE_V_FROM", from);
-		ss->set("MOVE_V_TO", to);
-		undoManager->action(this, ss);
-	}
-}
-
-void Page::moveYGuide(int fromIndex, double to)
-{
-	double from = YGuides[fromIndex];
-	undoManager->setUndoEnabled(false); // only want to store move action not remove/add actions related to it
-	removeYGuide(from);
-	addYGuide(to);
-	undoManager->setUndoEnabled(true);
-	if (UndoManager::undoEnabled())
-	{
-		SimpleState* ss = new SimpleState(Um::MoveHGuide, 0, Um::IGuides);
-		ss->set("MOVE_H_FROM", from);
-		ss->set("MOVE_H_TO", to);
-		undoManager->action(this, ss);
-	}
+		setUName(m_PageName);
 }
 
 void Page::setPageName(const QString& newName)
 {
-	PageNam = newName;
+	m_PageName = newName;
 	if (!newName.isEmpty())
 		setUName(QObject::tr("Master Page ") + newName);
 }
@@ -216,48 +96,37 @@ void Page::restore(UndoState* state, bool isUndo)
 		{
 			double position = ss->getDouble("ADD_V");
 			if (isUndo)
-				removeXGuide(position);
+				guides.deleteVertical(position, GuideManagerCore::Standard);//removeXGuide(position);
 			else
-				addXGuide(position);
+				guides.addVertical(position, GuideManagerCore::Standard);//addXGuide(position);
+			m_Doc->scMW()->guidePalette->setupGui();
 		}
 		else if (ss->contains("ADD_H"))
 		{
 			double position = ss->getDouble("ADD_H");
 			if (isUndo)
-				removeYGuide(position);
+				guides.deleteHorizontal(position, GuideManagerCore::Standard);//removeYGuide(position);
 			else
-				addYGuide(position);
+				guides.addHorizontal(position, GuideManagerCore::Standard);//addYGuide(position);
+			m_Doc->scMW()->guidePalette->setupGui();
 		}
 		else if (ss->contains("REMOVE_V"))
 		{
 			double position = ss->getDouble("REMOVE_V");
 			if (isUndo)
-				addXGuide(position);
+				guides.addVertical(position, GuideManagerCore::Standard);//addXGuide(position);
 			else
-				removeXGuide(position);
+				guides.deleteVertical(position, GuideManagerCore::Standard);//removeXGuide(position);
+			m_Doc->scMW()->guidePalette->setupGui();
 		}
 		else if (ss->contains("REMOVE_H"))
 		{
 			double position = ss->getDouble("REMOVE_H");
 			if (isUndo)
-				addYGuide(position);
+				guides.addHorizontal(position, GuideManagerCore::Standard);//addYGuide(position);
 			else
-				removeYGuide(position);
-		}
-		else if (ss->contains("MOVE_V_FROM"))
-		{
-			double from = ss->getDouble("MOVE_V_FROM");
-			double to   = ss->getDouble("MOVE_V_TO");
-			if (isUndo)
-			{
-				removeXGuide(to);
-				addXGuide(from);
-			}
-			else
-			{
-				removeXGuide(from);
-				addXGuide(to);
-			}
+				guides.deleteHorizontal(position, GuideManagerCore::Standard);//removeYGuide(position);
+			m_Doc->scMW()->guidePalette->setupGui();
 		}
 		else if (ss->contains("MOVE_H_FROM"))
 		{
@@ -265,14 +134,64 @@ void Page::restore(UndoState* state, bool isUndo)
 			double to   = ss->getDouble("MOVE_H_TO");
 			if (isUndo)
 			{
-				removeYGuide(to);
-				addYGuide(from);
+				guides.deleteHorizontal(to, GuideManagerCore::Standard);//removeYGuide(position);
+				guides.addHorizontal(from, GuideManagerCore::Standard);//addYGuide(position);
 			}
 			else
 			{
-				removeYGuide(from);
-				addYGuide(to);
+				guides.deleteHorizontal(from, GuideManagerCore::Standard);//removeYGuide(position);
+				guides.addHorizontal(to, GuideManagerCore::Standard);//addYGuide(position);
 			}
+			m_Doc->scMW()->guidePalette->setupGui();
+		}
+		else if (ss->contains("MOVE_V_FROM"))
+		{
+			double from = ss->getDouble("MOVE_V_FROM");
+			double to   = ss->getDouble("MOVE_V_TO");
+			if (isUndo)
+			{
+				guides.deleteVertical(to, GuideManagerCore::Standard);//removeXGuide(position);
+				guides.addVertical(from, GuideManagerCore::Standard);//removeXGuide(position);
+			}
+			else
+			{
+				guides.deleteVertical(from, GuideManagerCore::Standard);//removeXGuide(position);
+				guides.addVertical(to, GuideManagerCore::Standard);//removeXGuide(position);
+			}
+			m_Doc->scMW()->guidePalette->setupGui();
+		}
+		// automatic guides
+		else if (ss->contains("REMOVE_HA_GAP"))
+		{
+			if (isUndo)
+			{
+				guides.setHorizontalAutoCount(ss->getInt("REMOVE_HA_COUNT"));
+				guides.setHorizontalAutoGap(ss->getDouble("REMOVE_HA_GAP"));
+				guides.setHorizontalAutoRefer(ss->getInt("REMOVE_HA_REFER"));
+			}
+			else
+			{
+				guides.setHorizontalAutoCount(0);
+				guides.setHorizontalAutoGap(0.0);
+				guides.setHorizontalAutoRefer(0);
+			}
+			m_Doc->scMW()->guidePalette->setupGui();
+		}
+		else if (ss->contains("REMOVE_VA_GAP"))
+		{
+			if (isUndo)
+			{
+				guides.setVerticalAutoCount(ss->getInt("REMOVE_VA_COUNT"));
+				guides.setVerticalAutoGap(ss->getDouble("REMOVE_VA_GAP"));
+				guides.setVerticalAutoRefer(ss->getInt("REMOVE_VA_REFER"));
+			}
+			else
+			{
+				guides.setVerticalAutoCount(0);
+				guides.setVerticalAutoGap(0.0);
+				guides.setVerticalAutoRefer(0);
+			}
+			m_Doc->scMW()->guidePalette->setupGui();
 		}
 		else if (ss->contains("CREATE_ITEM"))
 			restorePageItemCreation(dynamic_cast<ItemState<PageItem*>*>(ss), isUndo);
@@ -287,81 +206,79 @@ void Page::restorePageItemCreation(ItemState<PageItem*> *state, bool isUndo)
 {
 	if (!state)
 		return;
-	ScMW->view->Deselect(true);
+	
 	PageItem *ite = state->getItem();
-	bool oldMPMode=ScMW->doc->masterPageMode();
-	ScMW->doc->setMasterPageMode(!ite->OnMasterPage.isEmpty());
-	if (ScMW->doc->EditClip)
-		ScMW->nodePalette->EndEdit();
+	bool oldMPMode=m_Doc->masterPageMode();
+	m_Doc->setMasterPageMode(!ite->OnMasterPage.isEmpty());
+	if (m_Doc->EditClip) // switch off from edit shape
+		m_Doc->scMW()->nodePalette->EndEdit();
 	if (isUndo)
 	{
-		if (ScMW->doc->m_Selection->findItem(ite)!=-1)
+		if (m_Doc->m_Selection->findItem(ite)!=-1)
 		{
-			if (ScMW->doc->appMode == modeEdit)
-				ScMW->setAppMode(modeNormal);
-			ScMW->doc->m_Selection->removeItem(ite);
+			if (m_Doc->appMode == modeEdit)
+				m_Doc->scMW()->setAppMode(modeNormal);
+			m_Doc->m_Selection->removeItem(ite);
 		}
-		Selection tempSelection(ScMW->doc, false);
+		m_Doc->view()->Deselect(true);
+		Selection tempSelection(m_Doc, false);
 		tempSelection.addItem(ite);
-		ScMW->doc->itemSelection_DeleteItem(&tempSelection, true);
+		m_Doc->itemSelection_DeleteItem(&tempSelection, false);
 		/*
-		ScMW->doc->m_Selection->clear();
-		ScMW->doc->m_Selection->addItem(ite, true);
-		ScMW->doc->itemSelection_DeleteItem();
-		ScMW->doc->m_Selection->clear();
+		m_Doc->m_Selection->clear();
+		m_Doc->m_Selection->addItem(ite, true);
+		m_Doc->itemSelection_DeleteItem();
+		m_Doc->m_Selection->clear();
 		*/
 	}
 	else
 	{
-		ScMW->doc->Items->append(ite);
-		ite->ItemNr = ScMW->doc->Items->count()-1;
+		m_Doc->view()->Deselect(true);
+		m_Doc->Items->append(ite);
+		ite->ItemNr = m_Doc->Items->count()-1;
+		m_Doc->view()->updateContents();
 	}
-	ScMW->view->updateContents();
-	ScMW->doc->setMasterPageMode(oldMPMode);
+	m_Doc->setMasterPageMode(oldMPMode);
 }
 
 void Page::restorePageItemDeletion(ItemState<PageItem*> *state, bool isUndo)
 {
 	if (!state)
 		return;
-	ScMW->view->Deselect(true);
+	m_Doc->view()->Deselect(true);
 	PageItem *ite = state->getItem();
-	bool oldMPMode=ScMW->doc->masterPageMode();
-	ScMW->doc->setMasterPageMode(!ite->OnMasterPage.isEmpty());
-	if (ScMW->doc->EditClip)
-		ScMW->nodePalette->EndEdit();
+	bool oldMPMode=m_Doc->masterPageMode();
+	m_Doc->setMasterPageMode(!ite->OnMasterPage.isEmpty());
+	if (m_Doc->EditClip) // switch off from edit shape
+		m_Doc->scMW()->nodePalette->EndEdit();
 	if (isUndo)
 	{
 		//CB #3373 reinsert at old position and renumber items
-		ScMW->doc->Items->insert(ite->ItemNr, ite);
-        for (uint a = 0; a < ScMW->doc->Items->count(); ++a)
-        {
-            ScMW->doc->Items->at(a)->ItemNr = a;
-        }
-		//ScMW->doc->Items->append(ite);
-		//ite->ItemNr = ScMW->doc->Items->count()-1;
-//		ScMW->view->updateContents();
+		m_Doc->Items->insert(ite->ItemNr, ite);
+		m_Doc->renumberItemsInListOrder();
+// 		m_Doc->Items->append(ite);
+// 		ite->ItemNr = m_Doc->Items->count()-1;
+ 		m_Doc->view()->updateContents();
 	}
 	else
 	{
-		if (ScMW->doc->m_Selection->findItem(ite)!=-1)
+		if (m_Doc->m_Selection->findItem(ite)!=-1)
 		{
-			if (ScMW->doc->appMode == modeEdit)
-				ScMW->setAppMode(modeNormal);
-			ScMW->doc->m_Selection->removeItem(ite);
+			if (m_Doc->appMode == modeEdit)
+				m_Doc->scMW()->setAppMode(modeNormal);
+			m_Doc->m_Selection->removeItem(ite);
 		}
-		Selection tempSelection(ScMW->doc, false);
+		Selection tempSelection(m_Doc, false);
 		tempSelection.addItem(ite);
-		ScMW->doc->itemSelection_DeleteItem(&tempSelection);
+		m_Doc->itemSelection_DeleteItem(&tempSelection);
 		/*
-		ScMW->doc->m_Selection->clear();
-		ScMW->doc->m_Selection->addItem(ite, true);
-		ScMW->doc->itemSelection_DeleteItem();
-		ScMW->doc->m_Selection->clear();
+		m_Doc->m_Selection->clear();
+		m_Doc->m_Selection->addItem(ite, true);
+		m_Doc->itemSelection_DeleteItem();
+		m_Doc->m_Selection->clear();
 		*/
 	}
-	ScMW->view->updateContents();
-	ScMW->doc->setMasterPageMode(oldMPMode);
+	m_Doc->setMasterPageMode(oldMPMode);
 }
 
 void Page::restorePageItemConversion(ItemState<std::pair<PageItem*, PageItem*> >*state, bool isUndo)
@@ -371,23 +288,23 @@ void Page::restorePageItemConversion(ItemState<std::pair<PageItem*, PageItem*> >
 
 	PageItem *oldItem=state->getItem().first;
 	PageItem *newItem=state->getItem().second;
-	bool oldMPMode=ScMW->doc->masterPageMode();
-	ScMW->doc->setMasterPageMode(!oldItem->OnMasterPage.isEmpty());
+	bool oldMPMode=m_Doc->masterPageMode();
+	m_Doc->setMasterPageMode(!oldItem->OnMasterPage.isEmpty());
 	if (isUndo)
 	{
-		ScMW->doc->Items->take(newItem->ItemNr);
-		ScMW->doc->Items->append(oldItem);
-		oldItem->ItemNr = ScMW->doc->Items->count()-1;
+		m_Doc->Items->take(newItem->ItemNr);
+		m_Doc->Items->append(oldItem);
+		oldItem->ItemNr = m_Doc->Items->count()-1;
 		oldItem->updatePolyClip();
-		ScMW->view->AdjustItemSize(oldItem);
+		m_Doc->AdjustItemSize(oldItem);
 	}
 	else
 	{
-		ScMW->doc->Items->take(oldItem->ItemNr);
-		ScMW->doc->Items->append(newItem);
-		newItem->ItemNr = ScMW->doc->Items->count()-1;
+		m_Doc->Items->take(oldItem->ItemNr);
+		m_Doc->Items->append(newItem);
+		newItem->ItemNr = m_Doc->Items->count()-1;
 	}
-	ScMW->doc->setMasterPageMode(oldMPMode);
+	m_Doc->setMasterPageMode(oldMPMode);
 }
 
 void Page::setXOffset(const double newCanvasXOffset)
@@ -429,13 +346,13 @@ void Page::copySizingProperties(Page* sourcePage, const MarginStruct& pageMargin
 {
 	if (sourcePage==NULL)
 		return;
-	PageSize = sourcePage->PageSize;
+	m_pageSize = sourcePage->m_pageSize;
 	PageOri = sourcePage->PageOri;
 	m_width=sourcePage->m_width;
 	m_height=sourcePage->m_height;
 	m_initialWidth = sourcePage->m_initialWidth;
 	m_initialHeight = sourcePage->m_initialHeight;
-	
+
 	Margins.Top = pageMargins.Top;
 	Margins.Bottom = pageMargins.Bottom;
 	Margins.Left = pageMargins.Left;//todo fix for layouts
