@@ -10,7 +10,6 @@ for which a new license (GPL+exception) is in place.
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
-#include "mspinbox.h"
 #include <qtoolbutton.h>
 #include <qlayout.h>
 #include <qtooltip.h>
@@ -18,11 +17,14 @@ for which a new license (GPL+exception) is in place.
 #include <qpainter.h>
 #include <qcursor.h>
 #include <qcolor.h>
+#include "commonstrings.h"
 #include "units.h"
 #include "scribusstructs.h"
+#include "mspinbox.h"
+
 extern QPixmap loadIcon(QString nam);
 
-RulerT::RulerT(QWidget *pa, int ein, QValueList<PageItem::TabRecord> Tabs, bool ind, double wid) : QWidget(pa)
+RulerT::RulerT(QWidget *pa, int ein, QValueList<ParagraphStyle::TabRecord> Tabs, bool ind, double wid) : QWidget(pa)
 {
 	setEraseColor(QColor(255,255,255));
 	unitIndex = ein;
@@ -54,6 +56,15 @@ RulerT::RulerT(QWidget *pa, int ein, QValueList<PageItem::TabRecord> Tabs, bool
 	}
 }
 
+void RulerT::setTabs(QValueList<ParagraphStyle::TabRecord> Tabs, int dEin)
+{
+	unitIndex = dEin;
+	iter=unitRulerGetIter1FromIndex(unitIndex);
+	iter2=unitRulerGetIter2FromIndex(unitIndex);
+	tabValues = Tabs;
+	repaint();
+}
+
 void RulerT::paintEvent(QPaintEvent *)
 {
 	double xl;
@@ -191,7 +202,7 @@ void RulerT::mousePressEvent(QMouseEvent *m)
 	}
 	if ((rulerCode == 0) && (m->button() == LeftButton))
 	{
-		struct PageItem::TabRecord tb;
+		ParagraphStyle::TabRecord tb;
 		tb.tabPosition = static_cast<double>(m->x() + offset);
 		tb.tabType = 0;
 		tb.tabFillChar = QChar();
@@ -230,7 +241,7 @@ void RulerT::mouseReleaseEvent(QMouseEvent *m)
 	{
 		if (rulerCode == 3)
 		{
-			QValueList<PageItem::TabRecord>::Iterator it;
+			QValueList<ParagraphStyle::TabRecord>::Iterator it;
 			it = tabValues.at(actTab);
 			tabValues.remove(it);
 			actTab = 0;
@@ -342,11 +353,11 @@ void RulerT::leaveEvent(QEvent*)
 
 void RulerT::updateTabList()
 {
-	struct PageItem::TabRecord tb;
+	ParagraphStyle::TabRecord tb;
 	tb.tabPosition = tabValues[actTab].tabPosition;
 	tb.tabType = tabValues[actTab].tabType;
 	tb.tabFillChar =  tabValues[actTab].tabFillChar;
-	QValueList<PageItem::TabRecord>::Iterator it;
+	QValueList<ParagraphStyle::TabRecord>::Iterator it;
 	int gg = static_cast<int>(tabValues.count()-1);
 	int g = gg;
 	it = tabValues.at(actTab);
@@ -445,7 +456,7 @@ void RulerT::moveLeftIndent(double t)
 	repaint();
 }
 
-Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, QValueList<PageItem::TabRecord> Tabs, double wid ) : QWidget( parent )
+Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, QValueList<ParagraphStyle::TabRecord> Tabs, double wid ) : QWidget( parent )
 {
 	docUnitRatio=unitGetRatioFromIndex(dEin);
 	double ww;
@@ -453,14 +464,7 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, QValueList<PageIt
 	setName( "tabruler" );
 	tabrulerLayout = new QVBoxLayout( this, 0, 6, "tabrulerLayout");
 	layout2 = new QHBoxLayout( 0, 0, 6, "layout2");
-	TypeCombo = new QComboBox( false, this, "TypeCombo" );
-	TypeCombo->clear();
-	TypeCombo->insertItem( tr( "Left" ) );
-	TypeCombo->insertItem( tr( "Right" ) );
-	TypeCombo->insertItem( tr( "Full Stop" ) );
-	TypeCombo->insertItem( tr( "Comma" ) );
-	TypeCombo->insertItem( tr( "Center" ) );
-	layout2->addWidget( TypeCombo );
+
 	rulerScrollL = new QToolButton( LeftArrow, this, "rulerScrollL" );
 	rulerScrollL->setAutoRepeat( true );
 	layout2->addWidget( rulerScrollL );
@@ -470,17 +474,25 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, QValueList<PageIt
 	rulerScrollR = new QToolButton( RightArrow, this, "RulserScrollR" );
 	rulerScrollR->setAutoRepeat( true );
 	layout2->addWidget( rulerScrollR );
-	tabrulerLayout->addLayout( layout2 );
+
 	layout1 = new QHBoxLayout( 0, 0, 6, "layout1" );
 	layout1->setAlignment( Qt::AlignTop );
-	tabData = new MSpinBox( 0, ww, this, 1 );
+	TypeCombo = new QComboBox( false, this, "TypeCombo" );
+	TypeCombo->clear();
+	TypeCombo->insertItem( tr( "Left" ) );
+	TypeCombo->insertItem( tr( "Right" ) );
+	TypeCombo->insertItem( tr( "Full Stop" ) );
+	TypeCombo->insertItem( tr( "Comma" ) );
+	TypeCombo->insertItem( tr( "Center" ) );
+	layout1->addWidget( TypeCombo );
+	tabData = new MSpinBox( 0, ww / docUnitRatio, this, 1 );
 	tabData->setValue(0);
 	positionLabel = new QLabel( tabData, tr("&Position:"), this, "positionLabel" );
 	layout1->addWidget( positionLabel );
 	layout1->addWidget( tabData );
 	tabFillCombo = new QComboBox( true, this, "tabFillCombo" );
 	tabFillCombo->setEditable(false);
-	tabFillCombo->insertItem( tr("None"), "tab fill");
+	tabFillCombo->insertItem( tr("None", "tab fill"));
 	tabFillCombo->insertItem( tr("Dot"));
 	tabFillCombo->insertItem( tr("Hyphen"));
 	tabFillCombo->insertItem( tr("Underscore"));
@@ -488,32 +500,53 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, QValueList<PageIt
 	tabFillComboT = new QLabel(tabFillCombo, tr( "Fill Char:" ), this, "tabFillComboT" );
 	layout1->addWidget( tabFillComboT );
 	layout1->addWidget( tabFillCombo );
+
+	layout4 = new QHBoxLayout(0, 0, 6, "layout3");
+
+	indentLayout = new QHBoxLayout(0, 0, 6, "indentLayout");
 	if (haveFirst)
 	{
-		firstLineData = new MSpinBox( -3000, ww, this, 1);
+		firstLineData = new MSpinBox( -3000, ww / docUnitRatio, this, 1);
 		firstLineData->setValue(0);
 		firstLineLabel = new QLabel( "", this, "firstLineLabel" );
 		firstLineLabel->setText("");
 		firstLineLabel->setPixmap(loadIcon("firstline.png"));
-		layout1->addWidget( firstLineLabel );
-		layout1->addWidget( firstLineData );
-		leftIndentData = new MSpinBox( 0, ww, this, 1 );
+		indentLayout->addWidget( firstLineLabel );
+		indentLayout->addWidget( firstLineData );
+		leftIndentData = new MSpinBox( 0, ww / docUnitRatio, this, 1 );
 		leftIndentData->setValue(0);
 		leftIndentLabel = new QLabel( "", this, "leftIndentLabel" );
 		leftIndentLabel->setText("");
 		leftIndentLabel->setPixmap(loadIcon("leftindent.png"));
-		layout1->addWidget( leftIndentLabel );
-		layout1->addWidget( leftIndentData );
+		layout4->addWidget( leftIndentLabel );
+		layout4->addWidget( leftIndentData );
+		layout4->addStretch(10);
+		rightIndentLabel = new QLabel("", this, "rightIndentLabel");
+		rightIndentLabel->setText("");
+		rightIndentLabel->setPixmap(loadIcon("rightindent.png"));
+		rightIndentData = new MSpinBox(0, ww / docUnitRatio, this, 1);
+		rightIndentData->setValue(0);
+		indentLayout->addWidget(rightIndentLabel);
+		indentLayout->addWidget(rightIndentData);
 	}
 	clearButton = new QPushButton( this, "clearButton" );
 	clearButton->setText( tr( "Delete All" ) );
-	layout1->addWidget( clearButton );
+	indentLayout->addSpacing(20);
+	indentLayout->addWidget( clearButton);
+	indentLayout->addStretch(10);
 	if (!haveFirst)
 	{
 		QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
 		layout1->addItem( spacer );
 	}
+	
+	layout1->addStretch( 10 );
 	tabrulerLayout->addLayout( layout1 );
+	tabrulerLayout->addLayout( layout2 );
+	indentLayout->addStretch( 10 );
+	tabrulerLayout->addLayout( indentLayout );
+	tabrulerLayout->addLayout(layout4);
+
 	TypeCombo->setEnabled(false);
 	tabData->setEnabled(false);
 	tabFillCombo->setEnabled(false);
@@ -535,15 +568,21 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, QValueList<PageIt
 	connect(ruler, SIGNAL(noTabs()), this, SLOT(lastTabRemoved()));
 	connect(tabData, SIGNAL(valueChanged(int)), this, SLOT(setTab()));
 	connect(clearButton, SIGNAL(clicked()), this, SLOT(clearAll()));
+	QToolTip::add( tabFillCombo, tr( "Fill Character of Tab" ) );
+	QToolTip::add( TypeCombo, tr( "Type/Orientation of Tab" ) );
+	QToolTip::add( tabData, tr( "Position of Tab" ) );
 	if (haveFirst)
 	{
 		connect(ruler, SIGNAL(firstLineMoved(double)) , this, SLOT(setFirstLineData(double)));
 		connect(ruler, SIGNAL(leftIndentMoved(double)) , this, SLOT(setLeftIndentData(double)));
 		connect(ruler, SIGNAL(mouseReleased()), this, SIGNAL(tabrulerChanged()));
+		connect(ruler, SIGNAL(mouseReleased()), this, SLOT(slotMouseReleased()));
 		connect(firstLineData, SIGNAL(valueChanged(int)), this, SLOT(setFirstLine()));
 		connect(leftIndentData, SIGNAL(valueChanged(int)), this, SLOT(setLeftIndent()));
+		connect(rightIndentData, SIGNAL(valueChanged(int)), this, SLOT(setRightIndent()));
 		QToolTip::add( firstLineData, tr( "Indentation for first line of the paragraph" ) );
 		QToolTip::add( leftIndentData, tr( "Indentation from the left for the whole paragraph" ) );
+		QToolTip::add( rightIndentData, tr( "Indentation from the right for the whole paragraph" ) );
 	}
 	QToolTip::add( clearButton, tr( "Delete all Tabulators" ) );
 	QString ein = unitGetSuffixFromIndex(dEin);
@@ -553,6 +592,7 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, QValueList<PageIt
 		{
 			firstLineData->setDecimals(10000);
 			leftIndentData->setDecimals(10000);
+			rightIndentData->setDecimals(10000);
 		}
 		tabData->setDecimals(10000);
 	}
@@ -560,11 +600,28 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, QValueList<PageIt
 	{
 		firstLineData->setSuffix(ein);
 		leftIndentData->setSuffix(ein);
+		rightIndentData->setSuffix(ein);
 	}
 	tabData->setSuffix(ein);
 	haveF = haveFirst;
 }
 
+void Tabruler::setTabs(QValueList<ParagraphStyle::TabRecord> Tabs, int dEin)
+{
+	docUnitRatio=unitGetRatioFromIndex(dEin);
+	QString ein = unitGetSuffixFromIndex(dEin);
+	tabData->setSuffix(ein);
+	if (haveF)
+	{
+		firstLineData->setSuffix(ein);
+		leftIndentData->setSuffix(ein);
+		rightIndentData->setSuffix(ein);
+	}
+	ruler->setTabs(Tabs, dEin);
+	if (Tabs.count() == 0)
+		clearButton->setEnabled(false);
+}
+
 void Tabruler::resetOFfL()
 {
 	if (!rulerScrollL->isDown())
@@ -583,6 +640,7 @@ void Tabruler::clearAll()
 	ruler->repaint();
 	lastTabRemoved();
 	emit tabrulerChanged();
+	emit tabsChanged();
 }
 
 void Tabruler::tabAdded()
@@ -592,6 +650,7 @@ void Tabruler::tabAdded()
 	clearButton->setEnabled(true);
 	tabFillCombo->setEnabled(true);
 	emit tabrulerChanged();
+	emit tabsChanged();
 }
 
 void Tabruler::lastTabRemoved()
@@ -601,6 +660,7 @@ void Tabruler::lastTabRemoved()
 	clearButton->setEnabled(false);
 	tabFillCombo->setEnabled(false);
 	emit tabrulerChanged();
+	emit tabsChanged();
 }
 
 void Tabruler::setFillChar()
@@ -628,7 +688,7 @@ void Tabruler::setFillChar()
 			break;
 		case 4:
 			tabFillCombo->setEditable(true);
-			tabFillCombo->setEditText( tr("Custom:"));
+			tabFillCombo->setEditText(CommonStrings::trCustomTabFill);
 			break;
 	}
 	if (tabFillCombo->currentItem() != 4)
@@ -639,7 +699,7 @@ void Tabruler::setFillChar()
 
 void Tabruler::setCustomFillChar(const QString &txt)
 {
-	if (txt == tr("Custom:"))
+	if (txt == CommonStrings::trCustomTabFill)
 		return;
 	disconnect(tabFillCombo, SIGNAL(textChanged(const QString &)), this, SLOT(setCustomFillChar(const QString &)));
 	disconnect(tabFillCombo, SIGNAL(activated(int)), this, SLOT(setFillChar()));
@@ -675,15 +735,17 @@ void Tabruler::setTabFillChar(QChar t)
 	{
 		tabFillCombo->setCurrentItem(4);
 		tabFillCombo->setEditable(true);
-		tabFillCombo->setEditText( tr("Custom: ")+QString(t));
+		tabFillCombo->setEditText(CommonStrings::trCustomTabFill+QString(t));
 	}
 	emit tabrulerChanged();
+	emit tabsChanged();
 }
 
 void Tabruler::setTabType(int t)
 {
 	TypeCombo->setCurrentItem(t);
 	emit tabrulerChanged();
+	emit tabsChanged();
 }
 
 void Tabruler::setType()
@@ -692,6 +754,7 @@ void Tabruler::setType()
 	ruler->changeTab(TypeCombo->currentItem());
 	connect(TypeCombo, SIGNAL(activated(int)), this, SLOT(setType()));
 	emit tabrulerChanged();
+	emit tabsChanged();
 }
 
 void Tabruler::setTabData(double t)
@@ -700,13 +763,17 @@ void Tabruler::setTabData(double t)
 	tabData->setValue(t * docUnitRatio);
 	connect(tabData, SIGNAL(valueChanged(int)), this, SLOT(setTab()));
 	if (!ruler->mousePressed)
+	{
 		emit tabrulerChanged();
+		emit tabsChanged();
+	}
 }
 
 void Tabruler::setTab()
 {
 	ruler->moveTab(tabData->value() / docUnitRatio);
 	emit tabrulerChanged();
+	emit tabsChanged();
 }
 
 void Tabruler::setFirstLineData(double t)
@@ -715,13 +782,23 @@ void Tabruler::setFirstLineData(double t)
 	firstLineData->setValue(t * docUnitRatio);
 	connect(firstLineData, SIGNAL(valueChanged(int)), this, SLOT(setFirstLine()));
 	if (!ruler->mousePressed)
+	{
 		emit tabrulerChanged();
+		double a, b, value;
+		int c;
+		firstLineData->getValues(&a, &b, &c, &value);
+		emit firstLineChanged(value);
+	}
 }
 
 void Tabruler::setFirstLine()
 {
 	ruler->moveFirstLine(firstLineData->value() / docUnitRatio);
 	emit tabrulerChanged();
+	double a, b, value;
+	int c;
+	firstLineData->getValues(&a, &b, &c, &value);
+	emit firstLineChanged(value);
 }
 
 void Tabruler::setLeftIndentData(double t)
@@ -730,16 +807,26 @@ void Tabruler::setLeftIndentData(double t)
 	leftIndentData->setValue(t * docUnitRatio);
 	connect(leftIndentData, SIGNAL(valueChanged(int)), this, SLOT(setLeftIndent()));
 	if (!ruler->mousePressed)
+	{
 		emit tabrulerChanged();
+		double a, b, value;
+		int c;
+		leftIndentData->getValues(&a, &b, &c, &value);
+		emit leftIndentChanged(value);
+	}
 }
 
 void Tabruler::setLeftIndent()
 {
 	ruler->moveLeftIndent(leftIndentData->value() / docUnitRatio);
 	emit tabrulerChanged();
+	double a, b, value;
+	int c;
+	leftIndentData->getValues(&a, &b, &c, &value);
+	emit leftIndentChanged(value);
 }
 
-QValueList<PageItem::TabRecord> Tabruler::getTabVals()
+QValueList<ParagraphStyle::TabRecord> Tabruler::getTabVals()
 {
 	return ruler->tabValues;
 }
@@ -753,3 +840,37 @@ double Tabruler::getLeftIndent()
 {
 	return leftIndentData->value() / docUnitRatio;
 }
+
+void Tabruler::setRightIndentData(double t)
+{
+	disconnect(rightIndentData, SIGNAL(valueChanged(int)), this, SLOT(setRightIndent()));
+	rightIndentData->setValue(t * docUnitRatio);
+	connect(rightIndentData, SIGNAL(valueChanged(int)), this, SLOT(setRightIndent()));
+	if (!ruler->mousePressed)
+	{
+		emit tabrulerChanged();
+		double a, b, value;
+		int c;
+		rightIndentData->getValues(&a, &b, &c, &value);
+		emit rightIndentChanged(value);
+	}
+}
+
+void Tabruler::setRightIndent()
+{
+	emit tabrulerChanged();
+	double a, b, value;
+	int c;
+	rightIndentData->getValues(&a, &b, &c, &value);
+	emit rightIndentChanged(value);
+}
+
+double Tabruler::getRightIndent()
+{
+	return rightIndentData->value() / docUnitRatio;
+}
+
+void Tabruler::slotMouseReleased()
+{
+	emit mouseReleased();
+}
